API Reference
==============

.. currentmodule:: gb_io

.. automodule:: gb_io


.. toctree::
   :hidden:

    Functions <functions>
    Record <record>
    Feature <feature>
    Reference <reference>
    Source <source>
    Qualifier <qualifier>
    Location <location>
    Reader <reader>


Functions
---------

.. autosummary::
    :nosignatures:

    load
    iter
    dump



Classes
-------

Record
^^^^^^

.. autosummary::
    :nosignatures:

    Record
    Feature
    Reference
    Source
    Qualifier


Locations
^^^^^^^^^

.. autosummary::
    :nosignatures:

    Location
    Between
    Bond
    Complement
    External
    Join
    OneOf
    Order
    Range


Reader
^^^^^^

.. autosummary::
    :nosignatures:

    RecordReader









